@@ -39,12 +39,12 @@ class AbstractRunner(ABC):
         self.save_model = save_model
         self.running_date = running_date
         self.starting_date = starting_date
-        self.minimize_drawdown = True
-        self.equaly_weighted = True
-        self.erc_weighted = True
-        self.ivp_allocation = True
-        self.mvp_allocation = True
-        self.hrp_allocation = True
+        self.minimize_drawdown = False
+        self.equaly_weighted = False
+        self.erc_weighted = False
+        self.ivp_allocation = False
+        self.mvp_allocation = False
+        self.hrp_allocation = False
         self.mdp_allocation = True
 
     @abstractmethod
@@ -55,9 +55,7 @@ class AbstractRunner(ABC):
 
 class SimpleEnsemblingRunner(AbstractRunner):
     def runTrial(self, saver, seed,  n, s, low_bound, up_bound):
-
         meArg = (seed, n, s, low_bound, up_bound)
-
         meArgList = list(meArg)
         meArgList = [str(it) for it in meArgList]
         savingKey = ''.join(meArgList)
@@ -76,7 +74,10 @@ class SimpleEnsemblingRunner(AbstractRunner):
         df = df.set_index('Date')
         df = df.fillna(method='ffill')
         df = df[df.index >= self.starting_date]
-        print('max ' + str(max(df.index)))
+        print('max before filtering ' + str(max(df.index)))
+        df = df[df.index <= self.running_date]
+
+        print('max after filtering ' + str(max(df.index)))
 
         check_drawdown_existence = saver.checkRunExistence('dd_'+savingKey)
         if self.minimize_drawdown and not check_drawdown_existence:
@@ -92,12 +93,19 @@ class SimpleEnsemblingRunner(AbstractRunner):
                 up_bound=up_bound,
                 filtering_threshold=0.9
             )
-            saver.saveResults('dd_'+savingKey, portfolio, weight_mat)
+            df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
+            weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
+            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            saver.saveResults('dd_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
 
         check_ew_existence = saver.checkRunExistence('ew_'+savingKey)
         if self.equaly_weighted and not check_ew_existence:
             print('equally weighted')
-            saver.saveResults('ew_'+savingKey, df_res.mean(axis=1), None)
+            df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
+            weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
+            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            saver.saveResults('ew_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
+
 
         check_erc_existence = saver.checkRunExistence('erc_'+savingKey)
         if self.erc_weighted and not check_erc_existence:
@@ -114,7 +122,11 @@ class SimpleEnsemblingRunner(AbstractRunner):
                 up_bound=up_bound,
                 filtering_threshold=0.9
             )
-            saver.saveResults('erc_'+savingKey, portfolio, None)
+            df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
+            weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
+            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            saver.saveResults('erc_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
+
 
         check_ivp_existence = saver.checkRunExistence('ivp_'+savingKey)
         if self.ivp_allocation and not check_ivp_existence:
@@ -131,7 +143,11 @@ class SimpleEnsemblingRunner(AbstractRunner):
                 up_bound=up_bound,
                 filtering_threshold=0.9
             )
-            saver.saveResults('ivp_'+savingKey, portfolio, weight_mat)
+            df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
+            weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
+            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            saver.saveResults('ivp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
+
 
 
         check_mpv_existence = saver.checkRunExistence('mvp_'+savingKey)
@@ -148,7 +164,11 @@ class SimpleEnsemblingRunner(AbstractRunner):
                 ret=False,
                 filtering_threshold=0.9
             )
-            saver.saveResults('mvp_'+savingKey, portfolio, weight_mat)
+            df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
+            weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
+            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            saver.saveResults('mvp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
+
 
         check_hrp_existence = saver.checkRunExistence('hrp_'+savingKey)
         if self.hrp_allocation and not check_hrp_existence:
@@ -167,7 +187,11 @@ class SimpleEnsemblingRunner(AbstractRunner):
                 low_bound=low_bound,
                 filtering_threshold=0.9
             )
-            saver.saveResults('hrp_'+savingKey, portfolio, weight_mat)
+            df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
+            weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
+            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            saver.saveResults('hrp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
+
 
         check_mdp_existence = saver.checkRunExistence('mdp_'+savingKey)
         if self.mdp_allocation and not check_mdp_existence:
@@ -185,7 +209,10 @@ class SimpleEnsemblingRunner(AbstractRunner):
                 low_bound=low_bound,
                 filtering_threshold=0.9
             )
-            saver.saveResults('mdp_'+savingKey, portfolio, weight_mat)
+            df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
+            weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
+            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            saver.saveResults('mdp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
 
 
 
