@@ -8,15 +8,12 @@ import pandas as pd
 from napoleontoolbox.file_saver import dropbox_file_saver
 from napoleontoolbox.utility import metrics
 from numpy.lib.stride_tricks import as_strided as stride
+from napoleontoolbox.signal import signal_generator
 
-def dd_threshold(data = None, threshold=1., contravariant = -1):
-    ratio = data['high'][-1]/data['high'][0]
-    if ratio > threshold:
-        return contravariant
-    else :
-        return -contravariant
+import json
 
-def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 0.001):
+
+def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4):
     data['turn_over'] = abs(data['signal'] - data['signal_gen']) / 2.
     print('average hourly turn over')
     print(data['turn_over'].sum() / len(data))
@@ -60,13 +57,14 @@ class AbstractRunner(ABC):
         self.starting_date = starting_date
 
     @abstractmethod
-    def runTrial(self,saver, seed,  look_back_window, threshold, contravariant):
+    def runTrial(self,saver, seed, signal_type, look_back_window, threshold, contravariant, idios):
         pass
 
 
 class SimpleSignalRunner(AbstractRunner):
-    def runTrial(self, saver, seed,  look_back_window, threshold, contravariant):
-        meArg = (seed,  look_back_window, threshold, contravariant)
+    def runTrial(self, saver, seed, signal_type, idios_string):
+        idios = json.loads(idios_string)
+        meArg = (seed,  signal_type,  idios_string)
         meArgList = list(meArg)
         meArgList = [str(it) for it in meArgList]
         savingKey = ''.join(meArgList)
@@ -76,15 +74,23 @@ class SimpleSignalRunner(AbstractRunner):
         savingKey = savingKey.replace(' ', '')
         savingKey = savingKey.replace('.', '')
         savingKey = savingKey.replace('-', 'minus')
+        savingKey = savingKey.replace('"', '')
+        savingKey = savingKey.replace('{', '')
+        savingKey = savingKey.replace('}', '')
+        savingKey = savingKey.replace(':', '')
+
         savingKey = 'T_' + savingKey
         print('Launching computation with parameters : '+savingKey)
-        skipping_size = look_back_window
+        lookback_window = idios['lookback_window']
+        skipping_size = lookback_window
+        #kwargs = {**generics, **idios}
+        signal_generation_method_to_call = getattr(signal_generator, signal_type)
         hourly_df = pd.read_pickle(self.local_root_directory+self.hourly_pkl_file_name)
-        hourly_df = roll_wrapper(hourly_df, look_back_window, skipping_size,
-                                  lambda x: dd_threshold(data=x, threshold=threshold, contravariant=contravariant))
+        hourly_df = roll_wrapper(hourly_df, lookback_window, skipping_size,
+                                  lambda x: signal_generation_method_to_call(data=x, **idios))
         hourly_df = reconstitute_signal_perf(hourly_df)
-        sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
-        sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period=252 * 24, from_ret=True)
+        sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period= 252 * 24, from_ret=True)
+        sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period= 252 * 24, from_ret=True)
         print('underlying sharpe')
         print(sharpe_under)
         print('strat sharpe')
