@@ -17,3 +17,14 @@ def lead_lag_indicator(data = None, lead=3, lag=5, contravariant = -1, **kwargs)
         return -contravariant
     else :
         return contravariant
+
+def volume_weighted_high_low_vol(data = None , threshold = 0.01):
+    data['hl'] = (data['high'] - data['low'])/data['low']
+    data['volu_hi_low'] = data['volume']*(data['high'] - data['low'])
+    volu_hi_low = data['volu_hi_low'].sum()
+    if volu_hi_low > threshold:
+        return 1
+    elif volu_hi_low < -threshold:
+        return -1
+    else :
+        return 0
\ No newline at end of file
